@@ -4,14 +4,14 @@ from pathlib import Path
 from coldtype.text import *
 from coldtype.text.reader import Font
 from coldtype.pens.datpenlikeobject import DATPenLikeObject
-from coldtype.pens.datpen import DATPen, DATPenSet
+from coldtype.pens.datpen import DATPen, DATPens, DATPenSet
 from coldtype.pens.dattext import DATText
 from coldtype.geometry import *
 from coldtype.color import *
 from coldtype.renderable import *
 from coldtype.helpers import *
-from coldtype.animation import *
+from coldtype.time import *
 #from coldtype.renderer.state import RendererState, Keylayer
 
 name = "coldtype"
-__version__ = "0.1.7"
\ No newline at end of file
+__version__ = "0.1.9"
\ No newline at end of file
