@@ -12,8 +12,8 @@ Style.RegisterShorthandPrefix("≈", "~/Type/fonts/fonts")
 
 
 def add_grid(render, result):
-    return DATPenSet([
-        DATPenSet(result),
+    return DATPens([
+        DATPens(result),
         DATPen().gridlines(render.rect).s(0, 0.1).sw(1)
     ])
 
