@@ -7,10 +7,10 @@ def mixed_visibility(r):
         .f(0.8)
         .v(1)
         .tag("circle"))
-    dps = DATPenSet([dp]).v(1)
-    dps2 = DATPenSet([
+    dps = DATPens([dp]).v(1)
+    dps2 = DATPens([
         dps,
         DATPen().oval(r.square()).f(hsl(0.3, a=0.25))
     ]).v(1)
-    dps3 = DATPenSet([dps2])
+    dps3 = DATPens([dps2])
     return dps3.v(1)
\ No newline at end of file
