@@ -10,7 +10,12 @@ states = [
 
 loop = Loop(120, len(states), 8)
 
-@animation(timeline=loop, storyboard=[110], bg=0)
+@animation(timeline=loop, storyboard=[0], bg=0)
 def render(f):
     state = f.a.t.current_phase(f.i).calc_state(states)
-    return StyledString("COLD", Style(co, 350, fill=0, **state, r=1)).pens().align(f.a.r).f(1).understroke()
\ No newline at end of file
+    return (StyledString("COLD",
+        Style(co, 350, fill=0, **state, r=1))
+        .pens()
+        .align(f.a.r)
+        .f(1)
+        .understroke())
\ No newline at end of file
