@@ -2,4 +2,4 @@ from coldtype.test import *
 
 @test(fmt="svg", rasterizer="skia")
 def test_simplest(r):
-    return DATPenSet().oval(r).f(hsl(random()))
\ No newline at end of file
+    return DATPens().oval(r).f(hsl(random()))
\ No newline at end of file
